summaryrefslogtreecommitdiff
path: root/src/Bottleneck_distance/concept
diff options
context:
space:
mode:
authorglisse <glisse@636b058d-ea47-450e-bf9e-a15bfbe3eedb>2017-01-21 22:49:02 +0000
committerglisse <glisse@636b058d-ea47-450e-bf9e-a15bfbe3eedb>2017-01-21 22:49:02 +0000
commitfb116961174a247dbb11278dba4deaed4bdf3eea (patch)
tree408ff98b6a83d4fc585d10f7bb75927e705fe78d /src/Bottleneck_distance/concept
parent636a3674c1c7b4ef63ee5141ec3d5aa0543762db (diff)
Tweaks to the doc of Bottleneck.
git-svn-id: svn+ssh://scm.gforge.inria.fr/svnroot/gudhi/branches/bottleneck-doc-glisse@1983 636b058d-ea47-450e-bf9e-a15bfbe3eedb Former-commit-id: 5300e7c4cfd3ffe22fa7ec906a4193d99d95453b
Diffstat (limited to 'src/Bottleneck_distance/concept')
-rw-r--r--src/Bottleneck_distance/concept/Persistence_diagram.h13
1 files changed, 7 insertions, 6 deletions
diff --git a/src/Bottleneck_distance/concept/Persistence_diagram.h b/src/Bottleneck_distance/concept/Persistence_diagram.h
index 2706716b..b157f22a 100644
--- a/src/Bottleneck_distance/concept/Persistence_diagram.h
+++ b/src/Bottleneck_distance/concept/Persistence_diagram.h
@@ -25,24 +25,25 @@
namespace Gudhi {
-namespace bottleneck_distance {
+namespace persistence_diagram {
-/** \brief Concept of Diagram_point. std::get<0>(point) must return the birth of the corresponding component and std::get<1>(point) its death.
+/** \brief Concept of point in a persistence diagram. std::get<0>(point) must return the birth of the corresponding component and std::get<1>(point) its death.
+ * Both should be convertible to `double`.
* A valid implementation of this concept is std::pair<double,double>.
* Death should be larger than birth, death can be std::numeric_limits<double>::infinity() for components which stay alive.
*
* \ingroup bottleneck_distance
*/
-typename Diagram_point;
+struct DiagramPoint{};
-/** \brief Concept of persistence diagram. It's a range of Diagram_point.
+/** \brief Concept of persistence diagram. It is a range of `DiagramPoint`.
* std::begin(diagram) and std::end(diagram) must return corresponding iterators.
*
* \ingroup bottleneck_distance
*/
-typename Persistence_Diagram;
+struct PersistenceDiagram{};
-} // namespace bottleneck_distance
+} // namespace persistence_diagram
} // namespace Gudhi